@@ -1,9 +1,10 @@
 from decimal import Decimal
 from types import SimpleNamespace
-from typing import Any, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
 from freshbooks.api.resource import HttpVerbs, Resource
 from freshbooks.builders import Builder
+from freshbooks.builders.includes import IncludesBuilder
 from freshbooks.errors import FreshBooksError, FreshBooksNotImplementedError
 from freshbooks.models import ListResult, Result
 
@@ -29,6 +30,19 @@ class ProjectsBaseResource(Resource):
 
         self.missing_endpoints = missing_endpoints or []
 
+    def _extract_error(self, error_response: Dict) -> Tuple[str, Optional[int], Optional[List[dict]]]:
+        code = error_response.get("errno")
+        message = error_response.get("message", "Unknown error")
+        details = []
+        if isinstance(error_response.get("error"), dict):
+            errors = error_response["error"]
+            for error_key in errors:  # could be reversed(errors) after dropping 3.7
+                details.append({error_key: errors[error_key]})
+                message = f"Error: {error_key} {errors[error_key]}"
+        else:
+            message = error_response.get("error", "Unknown error")
+        return message, code, details
+
     def _request(self, url: str, method: str, data: Optional[dict] = None) -> Any:
         response = self._send_request(url, method, data)
 
@@ -45,9 +59,8 @@ class ProjectsBaseResource(Resource):
             raise FreshBooksError(status, "Failed to parse response", raw_response=response.text)
 
         if status >= 400:
-            code = content.get("errno")
-            message = content.get("message") or content.get("error", "Unknown error")
-            raise FreshBooksError(status, message, error_code=code, raw_response=content)
+            message, code, details = self._extract_error(content)
+            raise FreshBooksError(status, message, error_code=code, error_details=details, raw_response=content)
         return content
 
     def _reject_missing(self, name: str) -> None:
@@ -66,12 +79,13 @@ class ProjectsResource(ProjectsBaseResource):
             return "{}/projects/business/{}/{}".format(self.base_url, business_id, self.list_resource_path)
         return "{}/projects/business/{}/{}".format(self.base_url, business_id, self.single_resource_path)
 
-    def get(self, business_id: int, resource_id: int) -> Result:
+    def get(self, business_id: int, resource_id: int, includes: Optional[IncludesBuilder] = None) -> Result:
         """Get a single resource with the corresponding id.
 
         Args:
             business_id: The business id
             resource_id: Id of the resource to return
+            includes: (Optional) IncludesBuilder object for including additional data, sub-resources, etc.
         Returns:
             Result: Result object with the resource's response data.
 
@@ -79,7 +93,11 @@ class ProjectsResource(ProjectsBaseResource):
             FreshBooksError: If the call is not successful.
         """
         self._reject_missing("get")
-        data = self._request(self._get_url(business_id, resource_id), HttpVerbs.GET)
+        resource_url = self._get_url(business_id, resource_id)
+        query_string = ""
+        if includes:
+            query_string = self._build_query_string([includes])
+        data = self._request(f"{resource_url}{query_string}", HttpVerbs.GET)
         return Result(self.single_name, data)
 
     def list(self, business_id: int, builders: Optional[List[Builder]] = None) -> ListResult:
