@@ -45,8 +45,8 @@ class IncludesBuilder(Builder):
         """Builds the query string parameters from the IncludesBuilder.
 
         Args:
-            resource_name: The type of resource to generate the query string for.
-                           Eg. AccountingResource, ProjectsResource
+            resource_name:
+                The type of resource to generate the query string for. Eg. AccountingResource, ProjectsResource
 
         Returns:
             The built query string
